#include "dialognewword.h"
#include "ui_dialognewword.h"

DialogNewWord::DialogNewWord(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::DialogNewWord)
{
    ui->setupUi(this);

    ui->lineEdit->setEnabled(false);
    //ui->kb->setScope(true);
    m_btOk = ui->btOk;
    //m_kb = new kb_Qwerty(this,true);
    m_kb = ui->kb;
    m_lineEdit = ui->lineEdit;
}

DialogNewWord::~DialogNewWord()
{
    delete ui;
}

void DialogNewWord::changeEvent(QEvent *e)
{
    QDialog::changeEvent(e);
    switch (e->type()) {
    case QEvent::LanguageChange:
        ui->retranslateUi(this);
        break;
    default:
        break;
    }
}
